@@ -27,12 +27,13 @@ GVApi::GVApi(bool bEmitLog, QObject *parent)
 : QObject(parent)
 , emitLog(bEmitLog)
 , loggedIn(false)
-, nwMgr(this)
+, nwMgr(NULL)
 , jar(new CookieJar(NULL))
 , dbgAlwaysFailDialing (false)
 , scriptEngine (this)
 {
-    nwMgr.setCookieJar (jar);
+    resetNwMgr ();
+    nwMgr->setCookieJar (jar);
 }//GVApi::GVApi
 
 bool
@@ -194,7 +195,8 @@ GVApi::beautify_number (QString &strNumber)
 }//GVApi::beautify_number
 
 bool
-GVApi::doGet(QUrl url, AsyncTaskToken *token, QObject *receiver, const char *method)
+GVApi::doGet(QUrl url, AsyncTaskToken *token, QObject *receiver,
+             const char *method)
 {
     if (!token) {
         return false;
@@ -205,12 +207,12 @@ GVApi::doGet(QUrl url, AsyncTaskToken *token, QObject *receiver, const char *met
 
     NwReqTracker::setCookies (jar, req);
 
-    QNetworkReply *reply = nwMgr.get(req);
+    QNetworkReply *reply = nwMgr->get(req);
     if (!reply) {
         return false;
     }
 
-    NwReqTracker *tracker = new NwReqTracker(reply, nwMgr, token,
+    NwReqTracker *tracker = new NwReqTracker(reply, *nwMgr, token,
                                         NW_REPLY_TIMEOUT, emitLog, true, this);
     if (!tracker) {
         reply->abort ();
@@ -223,8 +225,7 @@ GVApi::doGet(QUrl url, AsyncTaskToken *token, QObject *receiver, const char *met
     token->status = ATTS_SUCCESS;
 
     bool rv =
-    connect(tracker, SIGNAL (sigDone(bool, const QByteArray &, QNetworkReply *,
-                                     void *)),
+    connect(tracker, SIGNAL(sigDone(bool,const QByteArray&,QNetworkReply*,void*)),
             receiver, method);
     Q_ASSERT(rv);
     rv = connect(tracker, SIGNAL(sigProgress(double)),
@@ -256,13 +257,13 @@ GVApi::doPost(QUrl url, QByteArray postData, const char *contentType,
 
     NwReqTracker::setCookies (jar, req);
 
-    QNetworkReply *reply = nwMgr.post(req, postData);
+    QNetworkReply *reply = nwMgr->post(req, postData);
     if (!reply) {
         return false;
     }
 
     NwReqTracker *tracker =
-    new NwReqTracker(reply, nwMgr, token, NW_REPLY_TIMEOUT, emitLog, this);
+    new NwReqTracker(reply, *nwMgr, token, NW_REPLY_TIMEOUT, emitLog, this);
     if (!tracker) {
         reply->abort ();
         reply->deleteLater ();
@@ -2460,3 +2461,14 @@ GVApi::onCheckRecentInbox(bool success, const QByteArray &response,
         }
     }
 }//GVApi::onCheckRecentInbox
+
+void
+GVApi::resetNwMgr()
+{
+    if (NULL != nwMgr) {
+        nwMgr->deleteLater ();
+        nwMgr = NULL;
+    }
+
+    nwMgr = new QNetworkAccessManager(this);
+}//GVApi::resetNwMgr
