@@ -29,6 +29,7 @@ class CacheDatabase;
 class SkypeClientFactory;
 class ObserverFactory;
 class CallInitiatorFactory;
+class NwInfo;
 
 // For some reason the symbian MOC doesn't like it if I don't include QObject
 // even though it is present in QtCore which is included in global.h
@@ -44,15 +45,13 @@ public:
     ObserverFactory     & getObserverFactory ();
     SkypeClientFactory  & getSkypeFactory ();
     CallInitiatorFactory& getCIFactory ();
+    NwInfo              & getNwInfo ();
 
     void deinit();
 
 private:
     Singletons (QObject *parent = 0);
     virtual ~Singletons ();
-
-private:
-    CacheDatabase   *dbMain;
 };
 
 #include "GVDataAccess.h"
@@ -61,5 +60,6 @@ private:
 #include "ObserverFactory.h"
 #include "SkypeClientFactory.h"
 #include "CallInitiatorFactory.h"
+#include "NwInfo.h"
 
 #endif //__SINGLETONS_H__
