@@ -301,16 +301,6 @@ void qgv_LogFlush();
 #define MOBILE_OS 0
 #endif
 
-#if defined(QT_COMPONENTS_ADDED)
-#define USE_QT_COMPONENTS 1
-#else
-#define USE_QT_COMPONENTS 0
-#endif
-#if !(defined(Q_OS_SYMBIAN) || defined(MEEGO_HARMATTAN))
-#undef USE_QT_COMPONENTS
-#define USE_QT_COMPONENTS 0
-#endif
-
 #if defined(Q_WS_X11) && !defined(DISABLE_TELEPATHY)
 #define TELEPATHY_CAPABLE 1
 #else
@@ -341,6 +331,12 @@ void qgv_LogFlush();
 #define HAS_FUZZY_TIMER 0
 #endif
 
+#if defined(IS_S3) || defined(IS_S3_BELLE)
+#define HAS_SINGLE_APP 0
+#else
+#define HAS_SINGLE_APP 1
+#endif
+
 #if defined(Q_WS_X11)
 #define __FULLFUNC__ __PRETTY_FUNCTION__
 #else
